<?php

namespace Drupal\entity_timeline\Plugin\TimelineItemType\Deriver;

use Drupal\Core\Entity\Plugin\Condition\Deriver\EntityBundle as SourceEntityBundle;
use Drupal\Core\Plugin\Context\EntityContextDefinition;

/**
 * Deriver that creates a timeline item for each entity type with bundles.
 */
class EntityBundle extends SourceEntityBundle {

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition): array {
    foreach ($this->entityTypeManager->getDefinitions() as $id => $type) {
      $definition = $this->entityTypeManager->getDefinition($id);
      $table = $definition->getDataTable() ?? $definition->getBaseTable();
      if (!$table || !\Drupal::database()->schema()->fieldExists($table, 'uid')) {
        // Base entity must implement base or data table and owner.
        continue;
      }
      $this->derivatives[$id] = $base_plugin_definition;
      $this->derivatives[$id]['label'] = $type->hasKey('bundle') ? $type->getBundleLabel() : $type->getLabel();
      $this->derivatives[$id]['provider'] = $type->getProvider();
      $this->derivatives[$id]['context_definitions'] = [
        $id => EntityContextDefinition::fromEntityType($type),
      ];
    }
    return $this->derivatives;
  }

}
